@@ -13,11 +13,11 @@ Shell::Var::Reader::CMDB - Helper for updating shell_var_reader based CMDBs.
 
 =head1 VERSION
 
-Version 0.4.0
+Version 0.5.0
 
 =cut
 
-our $VERSION = '0.4.0';
+our $VERSION = '0.5.0';
 
 =head1 SUBROUTINES
 
@@ -160,6 +160,12 @@ sub update {
 		$munger_option = '-m ../munger.pl';
 	}
 
+	#
+	my $no_toml='';
+	if ( -f $opts{dir} . '/.no_toml' ) {
+		$no_toml = '--no_toml';
+	}
+
 	# get a list of directories to process and start work on it
 	chdir( $opts{dir} );
 	my @system_groups = grep {
@@ -204,6 +210,7 @@ sub update {
 						. shell_quote($system)
 						. ' --tcmdb ../cmdb/ -s -p --cmdb_host '
 						. shell_quote($cmdb_host) . ' '
+						. $no_toml . ' '
 						. $munger_option
 						. ' -o multi -d ../';
 					print `$command`;
@@ -243,6 +250,8 @@ Specifically named directories.
 Other directories that that don't start with a '.' or contiain a file named '.not_a_system_group'
 will be processed as system groups.
 
+TOML will be skipped if .no_toml exists in the base directory.
+
 These directories will be searched for files directly below them for files ending in '.sh' and not
 starting with either a '_' or a '.'. The name used for a system is the name of the file minus the ending
 '.sh', so 'foo.bar.sh' would generate a config for a system named 'foo.bar'.
